@@ -3,7 +3,7 @@
 
 /* 
  Authors
- Martin Schlather, martin.schlather@math.uni-goettingen.de
+ Martin Schlather, schlather@math.uni-mannheim.de
 
  Collection of auxiliary functions
 
